@@ -8,34 +8,22 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include "mainwin.h"
+#include "konquest_version.h"
 
 #include <KAboutData>
 #include <KCrash>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 #include <KDBusService>
 #include <KLocalizedString>
 
 #include <QApplication>
 #include <QCommandLineParser>
-#include "mainwin.h"
-#include "konquest_version.h"
 
 int
 main(int argc, char **argv)
 {
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("konquest"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("konquestrc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("konquestui.rc"));
-    migrate.migrate();
-#endif
+
     KLocalizedString::setApplicationDomain("konquest");
     KAboutData aboutData( QStringLiteral("konquest"), i18n("Konquest"),
         QStringLiteral(KONQUEST_VERSION_STRING),
@@ -52,12 +40,16 @@ main(int argc, char **argv)
     aboutData.addCredit(i18n("Pierre Ducroquet"), i18n("Cleaning and bugfixing, maintenance"), QStringLiteral("pinaraf@gmail.com"));
     aboutData.addCredit(i18n("Sean D'Epagnier"), i18n("Gameplay Enhancements"), QStringLiteral("geckosenator@gmail.com"));
 
-    QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("konquest")));
+
     KCrash::initialize();
+
+    QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
+
     KDBusService service;
 
     if (app.isSessionRestored())
@@ -66,6 +58,6 @@ main(int argc, char **argv)
         MainWindow *w = new MainWindow;
         w->show();
     }
-    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("konquest")));
+
     return app.exec();
 }
